@@ -4,7 +4,7 @@ import urwid
 
 
 def exit_on_q(key):
-    if key in ("q", "Q"):
+    if key in {"q", "Q"}:
         raise urwid.ExitMainLoop()
 
 
@@ -28,7 +28,7 @@ inside = urwid.AttrMap(div, "inside")
 txt = urwid.Text(("banner", " Hello World "), align="center")
 streak = urwid.AttrMap(txt, "streak")
 pile = loop.widget.base_widget  # .base_widget skips the decorations
-for item in [outside, inside, streak, inside, outside]:
+for item in (outside, inside, streak, inside, outside):
     pile.contents.append((item, pile.options()))
 
 loop.run()
