@@ -34,11 +34,9 @@ def received_output(data: bytes) -> bool:
 
 
 write_fd = loop.watch_pipe(received_output)
-proc = subprocess.Popen(
+with subprocess.Popen(
     ["python", "-u", run_me, str(factor_me)],  # noqa: S603,S607  # Example can be insecure
     stdout=write_fd,
     close_fds=True,
-)
-
-loop.run()
-proc.kill()
+) as proc:
+    loop.run()
