@@ -60,7 +60,7 @@ def separate_glyphs(gdata: str, height: int) -> tuple[dict[str, tuple[int, list[
             character = key_line[key_index]
 
         if key_index < len(key_line) and key_line[key_index] == character:
-            end_col += str_util.get_width(ord(character))
+            end_col += str_util.get_char_width(character)
             key_index += 1
             continue
 
@@ -76,7 +76,7 @@ def separate_glyphs(gdata: str, height: int) -> tuple[dict[str, tuple[int, list[
                 if j >= len(line):
                     fill = end_col - start_col - y
                     break
-                y += str_util.get_width(ord(line[j]))
+                y += str_util.get_char_width(line[j])
                 j += 1
             if y + fill != end_col - start_col:
                 raise ValueError(repr((y, fill, end_col)))
@@ -119,15 +119,15 @@ class FontRegistry(type):
 
     __registered: typing.ClassVar[dict[str, FontRegistry]] = {}
 
-    def __iter__(self) -> Iterator[str]:
+    def __iter__(cls) -> Iterator[str]:
         """Iterate over registered font names."""
-        return iter(self.__registered)
+        return iter(cls.__registered)
 
-    def __getitem__(self, item: str) -> FontRegistry | None:
+    def __getitem__(cls, item: str) -> FontRegistry | None:
         """Get font by name if registered."""
-        return self.__registered.get(item)
+        return cls.__registered.get(item)
 
-    def __class_getitem__(cls, item: str) -> FontRegistry | None:
+    def __class_getitem__(mcs, item: str) -> FontRegistry | None:
         """Get font by name if registered.
 
         This method is needed to get access to font from registry class.
@@ -142,7 +142,7 @@ class FontRegistry(type):
         >>> b'\\n'.join(canvas.text).decode('utf-8')
         '  \\n ┼\\n  '
         """
-        return cls.__registered.get(item)
+        return mcs.__registered.get(item)
 
     @property
     def registered(cls) -> Sequence[str]:
@@ -155,18 +155,18 @@ class FontRegistry(type):
         return list(mcs.__registered.items())
 
     def __new__(
-        cls: type[FontRegistry],
+        mcs: type[FontRegistry],
         name: str,
         bases: tuple[type, ...],
         namespace: dict[str, typing.Any],
         **kwds: typing.Any,
     ) -> FontRegistry:
         font_name: str = namespace.setdefault("name", kwds.get("font_name", ""))
-        font_class = super().__new__(cls, name, bases, namespace)
+        font_class = super().__new__(mcs, name, bases, namespace)
         if font_name:
-            if font_name not in cls.__registered:
-                cls.__registered[font_name] = font_class
-            if cls.__registered[font_name] != font_class:
+            if font_name not in mcs.__registered:
+                mcs.__registered[font_name] = font_class
+            if mcs.__registered[font_name] != font_class:
                 warnings.warn(
                     f"{font_name!r} is already registered, please override explicit if required or change name",
                     FontRegistryWarning,
